#!/bin/bash
#PBS -N hand_harvey
#PBS -e /gpfs_scratch/nfie/users/Harvey/hand-harvey.int32cm.stderr
#PBS -o /gpfs_scratch/nfie/users/Harvey/hand-harvey.int32cm.stdout
#PBS -l nodes=1:ppn=20,walltime=48:00:00
##PBS -l nodes=cg-gpu02:ppn=20+cg-gpu03:ppn=20+cg-gpu04:ppn=20+cg-gpu05:ppn=20+cg-gpu07:ppn=20+cg-gpu08:ppn=20+cg-gpu09:ppn=20+cg-cmp01:ppn=20+cg-cmp13:ppn=20,walltime=48:00:00
#PBS -M yanliu@ncsa.illinois.edu
#PBS -m be

## hand-harvey.sh: Height Above Nearest Drainage raster for harvey-affected area
## Author: Yan Y. Liu <yanliu.illinois.edu>
## Date: 09/01/2017

np=$PBS_NP
[ -z "$PBS_NP" ] && np=1

sdir=/projects/nfie/nfie-floodmap/test
source $sdir/softenv.forecast
source $sdir/handbyhuc.env

hucid=harvey
n=harvey
huc6list="120100 120200 120301 120302 120401 120402 120602 120701 120702 120901 120902 120903 120904 121001 121002 121003 121004 121101 121102"

rdir=/gpfs_scratch/nfie/users/Harvey
wdir=$rdir/hand
mkdir -p $wdir
cd $wdir

echo "[`date`] Running HAND workflow for HUC$hucid($n) using $np cores..."

# boundary shp buffering
wbd=$rdir/Tx_Counties_Harvey_zone/harvey_singleshape.shp
wbdlayer=`basename $wbd .shp`
bufferdist=0.01 # about 1.1km
echo "ogr2ogr -dialect sqlite -sql \"select ST_buffer(Geometry, $bufferdist) from '${wbdlayer}'\" ${n}-wbdbuf.shp $wbd  "
[ ! -f "${n}-wbdbuf.shp" ] && \
ogr2ogr -dialect sqlite -sql "select ST_buffer(Geometry, $bufferdist) from '${wbdlayer}'" ${n}-wbdbuf.shp $wbd  

# get flowlines
Tstart
whereclause=""
for h in $huc6list; do
	wc="REACHCODE like '${h}%'"
	if [ -z "$whereclause" ]; then
		whereclause="($wc)"
	else
		whereclause="$whereclause or ($wc)"
	fi
done
echo "ogr2ogr ${n}-flows.shp $dsnhdplus Flowline -where \"$whereclause\""
[ ! -f "${n}-flows.shp" ] && \
ogr2ogr ${n}-flows.shp $dsnhdplus Flowline -where "$whereclause"
Tcount flowline

# find inlet points
find_inlets=$sdir/../src/find_inlets/build/find_inlets 
Tstart
[ ! -f "${n}-inlets0.shp" ] && \
$find_inlets -flow ${n}-flows.shp -dangle ${n}-inlets0.shp 
Tcount dangle

# clip dem
Tstart
[ ! -f "${n}.tif" ] && \
gdalwarp -cutline ${n}-wbdbuf.shp -cl ${n}-wbdbuf -crop_to_cutline -of "GTiff" -overwrite -co "BIGTIFF=YES" $dsdem ${n}.tif 
Tcount dem

# rasterize inlets
Tstart
[ ! -f "${n}-weights.tif" ] && \
ogr2ogr -t_srs $dsepsg ${n}-inlets.shp ${n}-inlets0.shp && \
read fsizeDEM colsDEM rowsDEM nodataDEM xmin ymin xmax ymax cellsize_resx cellsize_resy<<<$(python $sdir/getRasterInfo.py ${n}.tif) && \
gdal_rasterize  -ot Int16 -of GTiff -burn 1 -tr $cellsize_resx $cellsize_resy -te $xmin $ymin $xmax $ymax ${n}-inlets.shp ${n}-weights.tif 
Tcount weights

# taudem pitremove
Tstart
[ ! -f "${n}fel.tif" ] && \
mpirun -np $np $taudem/pitremove -z ${n}.tif -fel ${n}fel.tif 
Tcount pitremove 

# taudem dinfflowdir
Tstart
[ ! -f "${n}ang.tif" ] && \
mpirun -np $np $taudemdinf -fel ${n}fel.tif -ang ${n}ang.tif -slp ${n}slp.tif 
Tcount dinf

# taudem d8flowdir
Tstart
[ ! -f "${n}p.tif" ] && \
mpirun -np $np $taudemd8 -fel ${n}fel.tif -p ${n}p.tif -sd8 ${n}sd8.tif 
Tcount d8

# taudem aread8
Tstart
[ ! -f "${n}ssa.tif" ] && \
mpirun -np $np $taudem/aread8 -p ${n}p.tif -ad8 ${n}ssa.tif -wg ${n}-weights.tif -nc 
Tcount aread8w

# taudem threshold
Tstart
[ ! -f "${n}src.tif" ] && \
mpirun -np $np $taudem/threshold -ssa ${n}ssa.tif -src ${n}src.tif -thresh 1 
Tcount threshold

# taudem dinfdistdown
Tstart
[ ! -f "${n}dd.tif" ] && \
mpirun -np $np $taudem/dinfdistdown -fel ${n}fel.tif -ang ${n}ang.tif -src ${n}src.tif -dd ${n}dd.tif -m ave v 
Tcount dinfdistdown

# clip to boundary
Tstart
[ ! -f "${n}hand.tif" ] && \
gdalwarp -cutline ${wbd} -cl ${wbdlayer} -crop_to_cutline -of "GTiff" -overwrite -co "BIGTIFF=YES" ${n}dd.tif ${n}handtmp.tif \
&& gdal_translate -of GTiff -co "COMPRESS=LZW" -co "BIGTIFF=YES" ${n}handtmp.tif ${n}hand.tif \
&& rm -f ${n}handtmp.tif 
Tcount hand

# convert to integer cm
[ ! -f "${n}hand_int32cm.tif" ] && \
/gpfs_scratch/taudem/TauDEM-CatchHydroGeo/handf2i -hand ${n}hand.tif -o ${n}hand_int32cm.tif

echo "[`date`] Finished."

